@@ -436,6 +436,14 @@ class VPacker(PackerBase):
     """
     VPacker packs its children vertically, automatically adjusting their
     relative positions at draw time.
+
+    .. code-block:: none
+
+       +---------+
+       | Child 1 |
+       | Child 2 |
+       | Child 3 |
+       +---------+
     """
 
     def _get_bbox_and_child_offsets(self, renderer):
@@ -468,6 +476,12 @@ class HPacker(PackerBase):
     """
     HPacker packs its children horizontally, automatically adjusting their
     relative positions at draw time.
+
+    .. code-block:: none
+
+       +-------------------------------+
+       | Child 1    Child 2    Child 3 |
+       +-------------------------------+
     """
 
     def _get_bbox_and_child_offsets(self, renderer):
@@ -498,6 +512,26 @@ class PaddedBox(OffsetBox):
 
     The `.PaddedBox` contains a `.FancyBboxPatch` that is used to visualize
     it when rendering.
+
+    .. code-block:: none
+
+       +----------------------------+
+       |                            |
+       |                            |
+       |                            |
+       | <--pad--> Artist           |
+       |             ^              |
+       |            pad             |
+       |             v              |
+       +----------------------------+
+
+    Attributes
+    ----------
+    pad : float
+        The padding in points.
+    patch : `.FancyBboxPatch`
+        When *draw_frame* is True, this `.FancyBboxPatch` is made visible and
+        creates a border around the box.
     """
 
     def __init__(self, child, pad=0., *, draw_frame=False, patch_attrs=None):
@@ -760,9 +794,10 @@ class TextArea(OffsetBox):
         return self._offset
 
     def get_bbox(self, renderer):
-        _, h_, d_ = renderer.get_text_width_height_descent(
-            "lp", self._text._fontproperties,
-            ismath="TeX" if self._text.get_usetex() else False)
+        _, h_, d_ = mtext._get_text_metrics_with_cache(
+            renderer, "lp", self._text._fontproperties,
+            ismath="TeX" if self._text.get_usetex() else False,
+            dpi=self.get_figure(root=True).dpi)
 
         bbox, info, yd = self._text._get_layout(renderer)
         w, h = bbox.size
@@ -1454,7 +1489,7 @@ class DraggableBase:
     def __init__(self, ref_artist, use_blit=False):
         self.ref_artist = ref_artist
         if not ref_artist.pickable():
-            ref_artist.set_picker(True)
+            ref_artist.set_picker(self._picker)
         self.got_artist = False
         self._use_blit = use_blit and self.canvas.supports_blit
         callbacks = self.canvas.callbacks
@@ -1468,6 +1503,11 @@ class DraggableBase:
             ]
         ]
 
+    @staticmethod
+    def _picker(artist, mouseevent):
+        # A custom picker to prevent dragging on mouse scroll events
+        return (artist.contains(mouseevent) and mouseevent.name != "scroll_event"), {}
+
     # A property, not an attribute, to maintain picklability.
     canvas = property(lambda self: self.ref_artist.get_figure(root=True).canvas)
     cids = property(lambda self: [
