@@ -13,6 +13,7 @@ import subprocess
 import sys
 from tempfile import TemporaryDirectory, TemporaryFile
 import weakref
+import re
 
 import numpy as np
 from PIL import Image
@@ -31,7 +32,7 @@ def make_test_filename(fname, purpose):
     Make a new filename by inserting *purpose* before the file's extension.
     """
     base, ext = os.path.splitext(fname)
-    return '%s-%s%s' % (base, purpose, ext)
+    return f'{base}-{purpose}{ext}'
 
 
 def _get_cache_path():
@@ -45,22 +46,20 @@ def get_cache_dir():
 
 
 def get_file_hash(path, block_size=2 ** 20):
-    md5 = hashlib.md5()
+    sha256 = hashlib.sha256(usedforsecurity=False)
     with open(path, 'rb') as fd:
         while True:
             data = fd.read(block_size)
             if not data:
                 break
-            md5.update(data)
+            sha256.update(data)
 
     if Path(path).suffix == '.pdf':
-        md5.update(str(mpl._get_executable_info("gs").version)
-                   .encode('utf-8'))
+        sha256.update(str(mpl._get_executable_info("gs").version).encode('utf-8'))
     elif Path(path).suffix == '.svg':
-        md5.update(str(mpl._get_executable_info("inkscape").version)
-                   .encode('utf-8'))
+        sha256.update(str(mpl._get_executable_info("inkscape").version).encode('utf-8'))
 
-    return md5.hexdigest()
+    return sha256.hexdigest()
 
 
 class _ConverterError(Exception):
@@ -103,14 +102,13 @@ class _GSConverter(_Converter):
         if not self._proc:
             self._proc = subprocess.Popen(
                 [mpl._get_executable_info("gs").executable,
-                 "-dNOSAFER", "-dNOPAUSE", "-sDEVICE=png16m"],
+                 "-dNOSAFER", "-dNOPAUSE", "-dEPSCrop", "-sDEVICE=png16m"],
                 # As far as I can see, ghostscript never outputs to stderr.
                 stdin=subprocess.PIPE, stdout=subprocess.PIPE)
             try:
                 self._read_until(b"\nGS")
-            except _ConverterError as err:
-                raise OSError(
-                    "Failed to start Ghostscript:\n\n" + err.args[0]) from None
+            except _ConverterError as e:
+                raise OSError(f"Failed to start Ghostscript:\n\n{e.args[0]}") from None
 
         def encode_and_escape(name):
             return (os.fsencode(name)
@@ -244,10 +242,8 @@ def _update_converter():
         converter['svg'] = _SVGConverter()
 
 
-#: A dictionary that maps filename extensions to functions which
-#: themselves map arguments `old` and `new` (filenames) to a list of strings.
-#: The list can then be passed to Popen to convert files with that
-#: extension to png format.
+#: A dictionary that maps filename extensions to functions which themselves
+#: convert between arguments `old` and `new` (filenames).
 converter = {}
 _update_converter()
 _svg_with_matplotlib_fonts_converter = _SVGWithMatplotlibFontsConverter()
@@ -279,7 +275,7 @@ def convert(filename, cache):
     """
     path = Path(filename)
     if not path.exists():
-        raise IOError(f"{path} does not exist")
+        raise OSError(f"{path} does not exist")
     if path.suffix[1:] not in converter:
         import pytest
         pytest.skip(f"Don't know how to convert {path.suffix} files to png")
@@ -303,7 +299,20 @@ def convert(filename, cache):
         convert = converter[path.suffix[1:]]
         if path.suffix == ".svg":
             contents = path.read_text()
-            if 'style="font:' in contents:
+            # NOTE: This check should be kept in sync with font styling in
+            # `lib/matplotlib/backends/backend_svg.py`. If it changes, then be sure to
+            # re-generate any SVG test files using this mode, or else such tests will
+            # fail to use the converter for the expected images (but will for the
+            # results), and the tests will fail strangely.
+            if re.search(
+                # searches for attributes :
+                #   style=[font|font-size|font-weight|
+                #          font-family|font-variant|font-style]
+                # taking care of the possibility of multiple style attributes
+                # before the font styling (i.e. opacity)
+                r'style="[^"]*font(|-size|-weight|-family|-variant|-style):',
+                contents  # raw contents of the svg file
+                    ):
                 # for svg.fonttype = none, we explicitly patch the font search
                 # path so that fonts shipped by Matplotlib are found.
                 convert = _svg_with_matplotlib_fonts_converter
@@ -339,7 +348,7 @@ def _clean_conversion_cache():
             path.unlink()
 
 
-@functools.lru_cache()  # Ensure this is only registered once.
+@functools.cache  # Ensure this is only registered once.
 def _register_conversion_cache_cleaner_once():
     atexit.register(_clean_conversion_cache)
 
@@ -361,8 +370,8 @@ def calculate_rms(expected_image, actual_image):
     """
     if expected_image.shape != actual_image.shape:
         raise ImageComparisonFailure(
-            "Image sizes do not match expected size: {} "
-            "actual size {}".format(expected_image.shape, actual_image.shape))
+            f"Image sizes do not match expected size: {expected_image.shape} "
+            f"actual size {actual_image.shape}")
     # Convert to float to avoid overflowing finite integer types.
     return np.sqrt(((expected_image - actual_image).astype(float) ** 2).mean())
 
@@ -432,14 +441,14 @@ def compare_images(expected, actual, tol, in_decorator=False):
     """
     actual = os.fspath(actual)
     if not os.path.exists(actual):
-        raise Exception("Output image %s does not exist." % actual)
+        raise Exception(f"Output image {actual} does not exist.")
     if os.stat(actual).st_size == 0:
-        raise Exception("Output image file %s is empty." % actual)
+        raise Exception(f"Output image file {actual} is empty.")
 
     # Convert the image to png
     expected = os.fspath(expected)
     if not os.path.exists(expected):
-        raise IOError('Baseline image %r does not exist.' % expected)
+        raise OSError(f'Baseline image {expected!r} does not exist.')
     extension = expected.split('.')[-1]
     if extension != 'png':
         actual = convert(actual, cache=True)
@@ -500,12 +509,12 @@ def save_diff_image(expected, actual, output):
     actual_image = _load_image(actual)
     actual_image, expected_image = crop_to_same(
         actual, actual_image, expected, expected_image)
-    expected_image = np.array(expected_image).astype(float)
-    actual_image = np.array(actual_image).astype(float)
+    expected_image = np.array(expected_image, float)
+    actual_image = np.array(actual_image, float)
     if expected_image.shape != actual_image.shape:
         raise ImageComparisonFailure(
-            "Image sizes do not match expected size: {} "
-            "actual size {}".format(expected_image.shape, actual_image.shape))
+            f"Image sizes do not match expected size: {expected_image.shape} "
+            f"actual size {actual_image.shape}")
     abs_diff = np.abs(expected_image - actual_image)
 
     # expand differences in luminance domain
