@@ -1,4 +1,5 @@
 from io import BytesIO
+import platform
 
 import numpy as np
 
@@ -19,31 +20,32 @@ def test_bbox_inches_tight():
             [78415, 81858, 150656, 193263, 69638],
             [139361, 331509, 343164, 781380, 52269]]
 
-    colLabels = rowLabels = [''] * 5
+    col_labels = row_labels = [''] * 5
 
     rows = len(data)
-    ind = np.arange(len(colLabels)) + 0.3  # the x locations for the groups
-    cellText = []
-    width = 0.4     # the width of the bars
-    yoff = np.zeros(len(colLabels))
+    ind = np.arange(len(col_labels)) + 0.3  # the x locations for the groups
+    cell_text = []
+    width = 0.4  # the width of the bars
+    yoff = np.zeros(len(col_labels))
     # the bottom values for stacked bar chart
     fig, ax = plt.subplots(1, 1)
     for row in range(rows):
         ax.bar(ind, data[row], width, bottom=yoff, align='edge', color='b')
         yoff = yoff + data[row]
-        cellText.append([''])
+        cell_text.append([''])
     plt.xticks([])
     plt.xlim(0, 5)
     plt.legend([''] * 5, loc=(1.2, 0.2))
     fig.legend([''] * 5, bbox_to_anchor=(0, 0.2), loc='lower left')
     # Add a table at the bottom of the axes
-    cellText.reverse()
-    plt.table(cellText=cellText, rowLabels=rowLabels, colLabels=colLabels,
+    cell_text.reverse()
+    plt.table(cellText=cell_text, rowLabels=row_labels, colLabels=col_labels,
               loc='bottom')
 
 
 @image_comparison(['bbox_inches_tight_suptile_legend'],
-                  remove_text=False, savefig_kwarg={'bbox_inches': 'tight'})
+                  savefig_kwarg={'bbox_inches': 'tight'},
+                  tol=0 if platform.machine() == 'x86_64' else 0.02)
 def test_bbox_inches_tight_suptile_legend():
     plt.plot(np.arange(10), label='a straight line')
     plt.legend(bbox_to_anchor=(0.9, 1), loc='upper left')
@@ -61,6 +63,30 @@ def test_bbox_inches_tight_suptile_legend():
     plt.xlabel('X axis')
 
 
+@image_comparison(['bbox_inches_tight_suptile_non_default.png'],
+                  savefig_kwarg={'bbox_inches': 'tight'},
+                  tol=0.1)  # large tolerance because only testing clipping.
+def test_bbox_inches_tight_suptitle_non_default():
+    fig, ax = plt.subplots()
+    fig.suptitle('Booo', x=0.5, y=1.1)
+
+
+@image_comparison(['bbox_inches_tight_layout.png'], remove_text=True,
+                  style='mpl20',
+                  savefig_kwarg=dict(bbox_inches='tight', pad_inches='layout'))
+def test_bbox_inches_tight_layout_constrained():
+    fig, ax = plt.subplots(layout='constrained')
+    fig.get_layout_engine().set(h_pad=0.5)
+    ax.set_aspect('equal')
+
+
+def test_bbox_inches_tight_layout_notconstrained(tmp_path):
+    # pad_inches='layout' should be ignored when not using constrained/
+    # compressed layout.  Smoke test that savefig doesn't error in this case.
+    fig, ax = plt.subplots()
+    fig.savefig(tmp_path / 'foo.png', bbox_inches='tight', pad_inches='layout')
+
+
 @image_comparison(['bbox_inches_tight_clipping'],
                   remove_text=True, savefig_kwarg={'bbox_inches': 'tight'})
 def test_bbox_inches_tight_clipping():
@@ -68,8 +94,8 @@ def test_bbox_inches_tight_clipping():
     # to generate an appropriately tight bbox
     plt.scatter(np.arange(10), np.arange(10))
     ax = plt.gca()
-    ax.set_xlim([0, 5])
-    ax.set_ylim([0, 5])
+    ax.set_xlim(0, 5)
+    ax.set_ylim(0, 5)
 
     # make a massive rectangle and clip it with a path
     patch = mpatches.Rectangle([-50, -50], 100, 100,
@@ -86,8 +112,7 @@ def test_bbox_inches_tight_clipping():
                   remove_text=True, savefig_kwarg={'bbox_inches': 'tight'})
 def test_bbox_inches_tight_raster():
     """Test rasterization with tight_layout"""
-    fig = plt.figure()
-    ax = fig.add_subplot(111)
+    fig, ax = plt.subplots()
     ax.plot([1.0, 2.0], rasterized=True)
 
 
@@ -118,14 +143,19 @@ def test_noop_tight_bbox():
     dpi = 100
     # make the figure just the right size up front
     fig = plt.figure(frameon=False, dpi=dpi, figsize=(x_size/dpi, y_size/dpi))
-    ax = plt.Axes(fig, [0., 0., 1., 1.])
-    fig.add_axes(ax)
+    ax = fig.add_axes((0, 0, 1, 1))
     ax.set_axis_off()
-    ax.get_xaxis().set_visible(False)
-    ax.get_yaxis().set_visible(False)
+    ax.xaxis.set_visible(False)
+    ax.yaxis.set_visible(False)
 
     data = np.arange(x_size * y_size).reshape(y_size, x_size)
-    ax.imshow(data)
+    ax.imshow(data, rasterized=True)
+
+    # When a rasterized Artist is included, a mixed-mode renderer does
+    # additional bbox adjustment. It should also be a no-op, and not affect the
+    # next save.
+    fig.savefig(BytesIO(), bbox_inches='tight', pad_inches=0, format='pdf')
+
     out = BytesIO()
     fig.savefig(out, bbox_inches='tight', pad_inches=0)
     out.seek(0)
@@ -133,3 +163,13 @@ def test_noop_tight_bbox():
     assert (im[:, :, 3] == 255).all()
     assert not (im[:, :, :3] == 255).all()
     assert im.shape == (7, 10, 4)
+
+
+@image_comparison(['bbox_inches_fixed_aspect'], extensions=['png'],
+                  remove_text=True, savefig_kwarg={'bbox_inches': 'tight'})
+def test_bbox_inches_fixed_aspect():
+    with plt.rc_context({'figure.constrained_layout.use': True}):
+        fig, ax = plt.subplots()
+        ax.plot([0, 1])
+        ax.set_xlim(0, 1)
+        ax.set_aspect('equal')
