@@ -11,6 +11,7 @@ import warnings
 import numpy as np
 import pytest
 
+import matplotlib as mpl
 from matplotlib.font_manager import (
     findfont, findSystemFonts, FontEntry, FontProperties, fontManager,
     json_dump, json_load, get_font, is_opentype_cff_font,
@@ -183,8 +184,8 @@ def test_addfont_as_path():
     path = Path(__file__).parent / font_test_file
     try:
         fontManager.addfont(path)
-        added, = [font for font in fontManager.ttflist
-                  if font.fname.endswith(font_test_file)]
+        added, = (font for font in fontManager.ttflist
+                  if font.fname.endswith(font_test_file))
         fontManager.ttflist.remove(added)
     finally:
         to_remove = [font for font in fontManager.ttflist
@@ -250,17 +251,22 @@ def test_missing_family(caplog):
 
 def _test_threading():
     import threading
-    from matplotlib.ft2font import LOAD_NO_HINTING
+    from matplotlib.ft2font import LoadFlags
     import matplotlib.font_manager as fm
 
+    def loud_excepthook(args):
+        raise RuntimeError("error in thread!")
+
+    threading.excepthook = loud_excepthook
+
     N = 10
     b = threading.Barrier(N)
 
     def bad_idea(n):
-        b.wait()
+        b.wait(timeout=5)
         for j in range(100):
             font = fm.get_font(fm.findfont("DejaVu Sans"))
-            font.set_text(str(n), 0.0, flags=LOAD_NO_HINTING)
+            font.set_text(str(n), 0.0, flags=LoadFlags.NO_HINTING)
 
     threads = [
         threading.Thread(target=bad_idea, name=f"bad_thread_{j}", args=(j,))
@@ -271,7 +277,9 @@ def _test_threading():
         t.start()
 
     for t in threads:
-        t.join()
+        t.join(timeout=9)
+        if t.is_alive():
+            raise RuntimeError("thread failed to join")
 
 
 def test_fontcache_thread_safe():
@@ -360,3 +368,42 @@ def test_donot_cache_tracebacks():
     for obj in gc.get_objects():
         if isinstance(obj, SomeObject):
             pytest.fail("object from inner stack still alive")
+
+
+def test_fontproperties_init_deprecation():
+    """
+    Test the deprecated API of FontProperties.__init__.
+
+    The deprecation does not change behavior, it only adds a deprecation warning
+    via a decorator. Therefore, the purpose of this test is limited to check
+    which calls do and do not issue deprecation warnings. Behavior is still
+    tested via the existing regular tests.
+    """
+    with pytest.warns(mpl.MatplotlibDeprecationWarning):
+        # multiple positional arguments
+        FontProperties("Times", "italic")
+
+    with pytest.warns(mpl.MatplotlibDeprecationWarning):
+        # Mixed positional and keyword arguments
+        FontProperties("Times", size=10)
+
+    with pytest.warns(mpl.MatplotlibDeprecationWarning):
+        # passing a family list positionally
+        FontProperties(["Times"])
+
+    # still accepted:
+    FontProperties(family="Times", style="italic")
+    FontProperties(family="Times")
+    FontProperties("Times")  # works as pattern and family
+    FontProperties("serif-24:style=oblique:weight=bold")  # pattern
+
+    # also still accepted:
+    # passing as pattern via family kwarg was not covered by the docs but
+    # historically worked. This is left unchanged for now.
+    # AFAICT, we cannot detect this: We can determine whether a string
+    # works as pattern, but that doesn't help, because there are strings
+    # that are both pattern and family. We would need to identify, whether
+    # a string is *not* a valid family.
+    # Since this case is not covered by docs, I've refrained from jumping
+    # extra hoops to detect this possible API misuse.
+    FontProperties(family="serif-24:style=oblique:weight=bold")
