@@ -1,26 +1,29 @@
 import difflib
+
 import numpy as np
-import subprocess
 import sys
 from pathlib import Path
 
 import pytest
 
 import matplotlib as mpl
+from matplotlib.testing import subprocess_run_for_testing
 from matplotlib import pyplot as plt
-from matplotlib.cbook import MatplotlibDeprecationWarning
 
 
-def test_pyplot_up_to_date(tmpdir):
+def test_pyplot_up_to_date(tmp_path):
+    pytest.importorskip("black")
+
     gen_script = Path(mpl.__file__).parents[2] / "tools/boilerplate.py"
     if not gen_script.exists():
         pytest.skip("boilerplate.py not found")
     orig_contents = Path(plt.__file__).read_text()
-    plt_file = tmpdir.join('pyplot.py')
+    plt_file = tmp_path / 'pyplot.py'
     plt_file.write_text(orig_contents, 'utf-8')
 
-    subprocess.run([sys.executable, str(gen_script), str(plt_file)],
-                   check=True)
+    subprocess_run_for_testing(
+        [sys.executable, str(gen_script), str(plt_file)],
+        check=True)
     new_contents = plt_file.read_text('utf-8')
 
     if orig_contents != new_contents:
@@ -40,8 +43,8 @@ def test_pyplot_up_to_date(tmpdir):
 
 
 def test_copy_docstring_and_deprecators(recwarn):
-    @mpl._api.rename_parameter("(version)", "old", "new")
-    @mpl._api.make_keyword_only("(version)", "kwo")
+    @mpl._api.rename_parameter(mpl.__version__, "old", "new")
+    @mpl._api.make_keyword_only(mpl.__version__, "kwo")
     def func(new, kwo=None):
         pass
 
@@ -54,9 +57,9 @@ def test_copy_docstring_and_deprecators(recwarn):
     wrapper_func(None, kwo=None)
     wrapper_func(new=None, kwo=None)
     assert not recwarn
-    with pytest.warns(MatplotlibDeprecationWarning):
+    with pytest.warns(mpl.MatplotlibDeprecationWarning):
         wrapper_func(old=None)
-    with pytest.warns(MatplotlibDeprecationWarning):
+    with pytest.warns(mpl.MatplotlibDeprecationWarning):
         wrapper_func(None, None)
 
 
@@ -206,7 +209,6 @@ def test_subplot_replace_projection():
     ax = plt.subplot(1, 2, 1)
     ax1 = plt.subplot(1, 2, 1)
     ax2 = plt.subplot(1, 2, 2)
-    # This will delete ax / ax1 as they fully overlap
     ax3 = plt.subplot(1, 2, 1, projection='polar')
     ax4 = plt.subplot(1, 2, 1, projection='polar')
     assert ax is not None
@@ -215,7 +217,7 @@ def test_subplot_replace_projection():
     assert ax3 is not ax
     assert ax3 is ax4
 
-    assert ax not in fig.axes
+    assert ax in fig.axes
     assert ax2 in fig.axes
     assert ax3 in fig.axes
 
@@ -228,12 +230,13 @@ def test_subplot_kwarg_collision():
     ax1 = plt.subplot(projection='polar', theta_offset=0)
     ax2 = plt.subplot(projection='polar', theta_offset=0)
     assert ax1 is ax2
+    ax1.remove()
     ax3 = plt.subplot(projection='polar', theta_offset=1)
     assert ax1 is not ax3
     assert ax1 not in plt.gcf().axes
 
 
-def test_gca_kwargs():
+def test_gca():
     # plt.gca() returns an existing axes, unless there were no axes.
     plt.figure()
     ax = plt.gca()
@@ -242,38 +245,16 @@ def test_gca_kwargs():
     assert ax1 is ax
     plt.close()
 
-    # plt.gca() raises a DeprecationWarning if called with kwargs.
-    plt.figure()
-    with pytest.warns(
-            MatplotlibDeprecationWarning,
-            match=r'Calling gca\(\) with keyword arguments was deprecated'):
-        ax = plt.gca(projection='polar')
-    ax1 = plt.gca()
-    assert ax is not None
-    assert ax1 is ax
-    assert ax1.name == 'polar'
-    plt.close()
-
-    # plt.gca() ignores keyword arguments if an axes already exists.
-    plt.figure()
-    ax = plt.gca()
-    with pytest.warns(
-            MatplotlibDeprecationWarning,
-            match=r'Calling gca\(\) with keyword arguments was deprecated'):
-        ax1 = plt.gca(projection='polar')
-    assert ax is not None
-    assert ax1 is ax
-    assert ax1.name == 'rectilinear'
-    plt.close()
-
 
 def test_subplot_projection_reuse():
-    # create an axes
+    # create an Axes
     ax1 = plt.subplot(111)
     # check that it is current
     assert ax1 is plt.gca()
     # make sure we get it back if we ask again
     assert ax1 is plt.subplot(111)
+    # remove it
+    ax1.remove()
     # create a polar plot
     ax2 = plt.subplot(111, projection='polar')
     assert ax2 is plt.gca()
@@ -281,6 +262,7 @@ def test_subplot_projection_reuse():
     assert ax1 not in plt.gcf().axes
     # assert we get it back if no extra parameters passed
     assert ax2 is plt.subplot(111)
+    ax2.remove()
     # now check explicitly setting the projection to rectilinear
     # makes a new axes
     ax3 = plt.subplot(111, projection='rectilinear')
@@ -302,15 +284,19 @@ def test_subplot_polar_normalization():
 
 
 def test_subplot_change_projection():
+    created_axes = set()
     ax = plt.subplot()
+    created_axes.add(ax)
     projections = ('aitoff', 'hammer', 'lambert', 'mollweide',
                    'polar', 'rectilinear', '3d')
     for proj in projections:
-        ax_next = plt.subplot(projection=proj)
-        assert ax_next is plt.subplot()
-        assert ax_next.name == proj
-        assert ax is not ax_next
-        ax = ax_next
+        ax.remove()
+        ax = plt.subplot(projection=proj)
+        assert ax is plt.subplot()
+        assert ax.name == proj
+        created_axes.add(ax)
+    # Check that each call created a new Axes.
+    assert len(created_axes) == 1 + len(projections)
 
 
 def test_polar_second_call():
@@ -337,6 +323,30 @@ def test_fallback_position():
                                axref.bbox.get_points())
 
 
+def test_set_current_figure_via_subfigure():
+    fig1 = plt.figure()
+    subfigs = fig1.subfigures(2)
+
+    plt.figure()
+    assert plt.gcf() != fig1
+
+    current = plt.figure(subfigs[1])
+    assert plt.gcf() == fig1
+    assert current == fig1
+
+
+def test_set_current_axes_on_subfigure():
+    fig = plt.figure()
+    subfigs = fig.subfigures(2)
+
+    ax = subfigs[0].subplots(1, squeeze=True)
+    subfigs[1].subplots(1, squeeze=True)
+
+    assert plt.gca() != ax
+    plt.sca(ax)
+    assert plt.gca() == ax
+
+
 def test_pylab_integration():
     IPython = pytest.importorskip("IPython")
     mpl.testing.subprocess_run_helper(
@@ -345,7 +355,131 @@ def test_pylab_integration():
         "-c",
         ";".join((
             "import matplotlib.pyplot as plt",
-            "assert plt._IP_REGISTERED is not None",
+            "assert plt._REPL_DISPLAYHOOK == plt._ReplDisplayHook.IPYTHON",
         )),
         timeout=60,
     )
+
+
+def test_doc_pyplot_summary():
+    """Test that pyplot_summary lists all the plot functions."""
+    pyplot_docs = Path(__file__).parent / '../../../doc/api/pyplot_summary.rst'
+    if not pyplot_docs.exists():
+        pytest.skip("Documentation sources not available")
+
+    def extract_documented_functions(lines):
+        """
+        Return a list of all the functions that are mentioned in the
+        autosummary blocks contained in *lines*.
+
+        An autosummary block looks like this::
+
+            .. autosummary::
+               :toctree: _as_gen
+               :template: autosummary.rst
+               :nosignatures:
+
+               plot
+               plot_date
+
+        """
+        functions = []
+        in_autosummary = False
+        for line in lines:
+            if not in_autosummary:
+                if line.startswith(".. autosummary::"):
+                    in_autosummary = True
+            else:
+                if not line or line.startswith("   :"):
+                    # empty line or autosummary parameter
+                    continue
+                if not line[0].isspace():
+                    # no more indentation: end of autosummary block
+                    in_autosummary = False
+                    continue
+                functions.append(line.strip())
+        return functions
+
+    lines = pyplot_docs.read_text().split("\n")
+    doc_functions = set(extract_documented_functions(lines))
+    plot_commands = set(plt._get_pyplot_commands())
+    missing = plot_commands.difference(doc_functions)
+    if missing:
+        raise AssertionError(
+            f"The following pyplot functions are not listed in the "
+            f"documentation. Please add them to doc/api/pyplot_summary.rst: "
+            f"{missing!r}")
+    extra = doc_functions.difference(plot_commands)
+    if extra:
+        raise AssertionError(
+            f"The following functions are listed in the pyplot documentation, "
+            f"but they do not exist in pyplot. "
+            f"Please remove them from doc/api/pyplot_summary.rst: {extra!r}")
+
+
+def test_minor_ticks():
+    plt.figure()
+    plt.plot(np.arange(1, 10))
+    tick_pos, tick_labels = plt.xticks(minor=True)
+    assert np.all(tick_labels == np.array([], dtype=np.float64))
+    assert tick_labels == []
+
+    plt.yticks(ticks=[3.5, 6.5], labels=["a", "b"], minor=True)
+    ax = plt.gca()
+    tick_pos = ax.get_yticks(minor=True)
+    tick_labels = ax.get_yticklabels(minor=True)
+    assert np.all(tick_pos == np.array([3.5, 6.5]))
+    assert [l.get_text() for l in tick_labels] == ['a', 'b']
+
+
+def test_switch_backend_no_close():
+    plt.switch_backend('agg')
+    fig = plt.figure()
+    fig = plt.figure()
+    assert len(plt.get_fignums()) == 2
+    plt.switch_backend('agg')
+    assert len(plt.get_fignums()) == 2
+    plt.switch_backend('svg')
+    assert len(plt.get_fignums()) == 2
+
+
+def figure_hook_example(figure):
+    figure._test_was_here = True
+
+
+def test_figure_hook():
+
+    test_rc = {
+        'figure.hooks': ['matplotlib.tests.test_pyplot:figure_hook_example']
+    }
+    with mpl.rc_context(test_rc):
+        fig = plt.figure()
+
+    assert fig._test_was_here
+
+
+def test_multiple_same_figure_calls():
+    fig = plt.figure(1, figsize=(1, 2))
+    with pytest.warns(UserWarning, match="Ignoring specified arguments in this call"):
+        fig2 = plt.figure(1, figsize=np.array([3, 4]))
+    with pytest.warns(UserWarning, match="Ignoring specified arguments in this call"):
+        plt.figure(fig, figsize=np.array([5, 6]))
+    assert fig is fig2
+    fig3 = plt.figure(1)  # Checks for false warnings
+    assert fig is fig3
+
+
+def test_close_all_warning():
+    fig1 = plt.figure()
+
+    # Check that the warning is issued when 'all' is passed to plt.figure
+    with pytest.warns(UserWarning, match="closes all existing figures"):
+        fig2 = plt.figure("all")
+
+
+def test_matshow():
+    fig = plt.figure()
+    arr = [[0, 1], [1, 2]]
+
+    # Smoke test that matshow does not ask for a new figsize on the existing figure
+    plt.matshow(arr, fignum=fig.number)
